@@ -166,7 +166,7 @@ class SignalParalleLauncher():
             sqliteConnection = sqlite3.connect(self.db_path)
             cursor = sqliteConnection.cursor()
             for i, v in values.iteritems():
-                sqlite_update_query = """UPDATE 'parallel_signals' set '""" + run + """' = '""" + str(
+                sqlite_update_query = """UPDATE 'parallel_signal' set '""" + run + """' = '""" + str(
                     v) + """' where effective_date = '""" + str(i) + """'"""
                 cursor.execute(sqlite_update_query)
             sqliteConnection.commit()
@@ -292,7 +292,7 @@ class SignalParalleLauncher():
 
     def saveAll(self,run, strat_results_df):
         self.saveResults(run, strat_results_df['reconstituted_perf'])
-        self.saveSignals(run, strat_results_df['reconstituted_perf'])
+        self.saveSignals(run, strat_results_df['signal'])
 
     def saveResults(self, run, strat_results_df):
         self.addRun(run)
