@@ -76,7 +76,49 @@ class ParallelRunResultAnalyzer():
                 print("The Sqlite connection is closed")
         return results_df
 
-    def analyzeAllRunResults(self,jsonized_output = True):
+    def analyzeAllRunResults(self,jsonized_output = True ):
+        results_df = self.analyzeAllRunPerfResults(jsonized_output=jsonized_output)
+        signals_df = self.analyzeAllRunSignalsResults(jsonized_output=jsonized_output)
+        return results_df, signals_df
+
+    def analyzeAllRunSignalsResults(self,jsonized_output = True):
+        sqliteConnection = None
+        try:
+            sqliteConnection = sqlite3.connect(self.db_path, timeout=20)
+            sqlite_select_run_query = """SELECT * from parallel_signal order by effective_date asc"""
+            results_df = pd.read_sql_query(sqlite_select_run_query, sqliteConnection)
+        except sqlite3.Error as error:
+            print("Failed to read data from sqlite table", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("The Sqlite connection is closed")
+
+        results_df = results_df.rename(columns={"effective_date": "Date"})
+        results_df['Date'] = pd.to_datetime(results_df['Date'])
+        results_df = results_df.sort_values(by=['Date'])
+        results_df = results_df.set_index(results_df['Date'])
+        results_df = results_df.drop(['Date'], axis=1)
+
+        run_empty_results = results_df.sum(axis = 0)
+        self.empty_runs_to_investigate = list(run_empty_results.index[run_empty_results == 0])
+
+        results_df = results_df.drop(columns=self.empty_runs_to_investigate)
+
+        if not jsonized_output :
+            renaming_dictionary = {}
+            for col in results_df.columns:
+                if col != 'Date':
+                    run_json_string=signal_utility.recover_to_sql_column_format(col)
+                    params = json.loads(run_json_string)
+                    #salty = hashlib.sha256(run_json_string)
+                    salty =str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
+                    renaming_dictionary[col] = params['signal_type']+str(params['transaction_costs'])+str(params['normalization'])+salty
+
+            results_df = results_df.rename(columns=renaming_dictionary, errors="raise")
+        return results_df
+
+    def analyzeAllRunPerfResults(self,jsonized_output = True):
         sqliteConnection = None
         try:
             sqliteConnection = sqlite3.connect(self.db_path, timeout=20)
