@@ -246,7 +246,7 @@ def HRC(X, low_bound=0., up_bound=1.0, nb_clusters = 10):
     low_bound = min(low_bound, 1 / X.shape[1])
 
     # Compute covariance and correlation matrix
-    correl_mat = X.corr().fillna(0).valuesfro
+    correl_mat = X.corr().fillna(0).values
 
     dist = 1 - correl_mat
     dim = len(dist)
